==> haskell-th-utilities-0.2.0.1-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-utilities
version: 0.2.0.1
id: th-utilities-0.2.0.1-58DQqcf2Z7w4UakiXPtoml
key: th-utilities-0.2.0.1-58DQqcf2Z7w4UakiXPtoml
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/th-utilities#readme
synopsis: Collection of useful functions for use with Template Haskell
category: Template Haskell
abi: 589c792985d598f596a75941cb785609
exposed: True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.ReifySimple TH.RelativePaths
    TH.Utilities
hidden-modules: TH.Derive.Internal
import-dirs: /usr/lib/ghc-8.4.2/site-local/th-utilities-0.2.0.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/th-utilities-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/th-utilities-0.2.0.1
hs-libraries: HSth-utilities-0.2.0.1-58DQqcf2Z7w4UakiXPtoml
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    directory-1.3.1.5 filepath-1.4.2
    primitive-0.6.3.0-DaZpcxwJp2TGn8ITSgfI4C
    syb-0.7-2jW43lwzJV5e7EQvU8PxV template-haskell-2.13.0.0
    text-1.2.3.0 th-orphans-0.13.5-67S3xnF4wCQ1Uvh2CbO9OD
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             directory-1.3.1.5=c4ddb2059d4b7fed7d39b1d1bb3bf41d
             filepath-1.4.2=a70b79acbde9ca897bdc5eadf9254ba7
             primitive-0.6.3.0-DaZpcxwJp2TGn8ITSgfI4C=16a73b69e52691069991327a53e4d794
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=8c8a6a5165e3238217c6cf4f5b6db1bc
             template-haskell-2.13.0.0=b25d144eee230069f091d0d8982b331b
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             th-orphans-0.13.5-67S3xnF4wCQ1Uvh2CbO9OD=365417fe0de20e45f1893990200ed7eb
haddock-interfaces: /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock
haddock-html: /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-utilities-0.2.0.1-40-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-utilities
version: 0.2.0.1
id: th-utilities-0.2.0.1-5c8gwflTCEf59KisuekHCB
key: th-utilities-0.2.0.1-5c8gwflTCEf59KisuekHCB
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/th-utilities#readme
synopsis: Collection of useful functions for use with Template Haskell
category: Template Haskell
abi: 6faffca6216cd16d559b59f79117c10d
exposed: True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.ReifySimple TH.RelativePaths
    TH.Utilities
hidden-modules: TH.Derive.Internal
import-dirs: /usr/lib/ghc-8.4.2/site-local/th-utilities-0.2.0.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/th-utilities-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/th-utilities-0.2.0.1
hs-libraries: HSth-utilities-0.2.0.1-5c8gwflTCEf59KisuekHCB
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    directory-1.3.1.5 filepath-1.4.2
    primitive-0.6.3.0-DaZpcxwJp2TGn8ITSgfI4C
    syb-0.7-2jW43lwzJV5e7EQvU8PxV template-haskell-2.13.0.0
    text-1.2.3.0 th-orphans-0.13.5-BoQ31XWA8s57WslbKFAlfk
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             directory-1.3.1.5=c4ddb2059d4b7fed7d39b1d1bb3bf41d
             filepath-1.4.2=a70b79acbde9ca897bdc5eadf9254ba7
             primitive-0.6.3.0-DaZpcxwJp2TGn8ITSgfI4C=16a73b69e52691069991327a53e4d794
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=8c8a6a5165e3238217c6cf4f5b6db1bc
             template-haskell-2.13.0.0=b25d144eee230069f091d0d8982b331b
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             th-orphans-0.13.5-BoQ31XWA8s57WslbKFAlfk=eefddcd0b2e04653eb1ef245c1c72a94
haddock-interfaces: /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock
haddock-html: /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
